workflows

package
v0.0.0-...-17db60d Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 17, 2024 License: Apache-2.0 Imports: 7 Imported by: 0

Documentation

Index

Constants

const (
	PaymentQuery            = "payment"
	PaymentSubmissionUpdate = "payment-submission"
)

Variables

var ErrExpired = errors.New("workflow expired")
var ErrRejected = errors.New("workflow rejected")

Functions

func NewPaymentWorkflowId

func NewPaymentWorkflowId() types.UUID

Types

type PaymentState

type PaymentState = model.Payment

type PaymentSubmissionInput

type PaymentSubmissionInput struct {
	SourceWalletId string
	UsdAmount      types.Decimal
}

type PaymentWorkflowInput

type PaymentWorkflowInput struct {
	Amount      types.Decimal
	Currency    string
	Destination types.UUID
}

type PaymentWorkflowResult

type PaymentWorkflowResult = PaymentState

func Payment

func Payment(ctx workflow.Context, paymentId types.UUID, input *PaymentWorkflowInput) (*PaymentWorkflowResult, error)

Payment is a Workflow Definition that calls for the execution of a variable set of Activities and Child Workflows. This is the main entry point of the application.

Jump to