Documentation
¶
Index ¶
Constants ¶
const ( PaymentQuery = "payment" PaymentSubmissionUpdate = "payment-submission" )
Variables ¶
var ErrExpired = errors.New("workflow expired")
var ErrRejected = errors.New("workflow rejected")
Functions ¶
func NewPaymentWorkflowId ¶
Types ¶
type PaymentState ¶
type PaymentSubmissionInput ¶
type PaymentWorkflowInput ¶
type PaymentWorkflowResult ¶
type PaymentWorkflowResult = PaymentState
func Payment ¶
func Payment(ctx workflow.Context, paymentId types.UUID, input *PaymentWorkflowInput) (*PaymentWorkflowResult, error)
Payment is a Workflow Definition that calls for the execution of a variable set of Activities and Child Workflows. This is the main entry point of the application.
Click to show internal directories.
Click to hide internal directories.